@@ -28,6 +28,7 @@ import time
 from absl import logging
 
 from dopamine.agents.dqn import dqn_agent
+from dopamine.jax import losses
 from dopamine.jax import networks
 from dopamine.replay_memory import circular_replay_buffer
 from dopamine.replay_memory import prioritized_replay_buffer
@@ -52,7 +53,7 @@ def create_optimizer(name='adam', learning_rate=6.25e-5, beta1=0.9, beta2=0.999,
                      eps=1.5e-4, centered=False):
   """Create an optimizer for training.
 
-  Currently, only the Adam optimizer is supported.
+  Currently, only the Adam and RMSProp optimizers are supported.
 
   Args:
     name: str, name of the optimizer to create.
@@ -79,16 +80,9 @@ def create_optimizer(name='adam', learning_rate=6.25e-5, beta1=0.9, beta2=0.999,
     raise ValueError('Unsupported optimizer {}'.format(name))
 
 
-def huber_loss(targets, predictions, delta=1.0):
-  x = jnp.abs(targets - predictions)
-  return jnp.where(x <= delta,
-                   0.5 * x**2,
-                   0.5 * delta**2 + delta * (x - delta))
-
-
-@functools.partial(jax.jit, static_argnums=(0, 8))
+@functools.partial(jax.jit, static_argnums=(0, 8, 9))
 def train(network_def, target_params, optimizer, states, actions, next_states,
-          rewards, terminals, cumulative_gamma):
+          rewards, terminals, cumulative_gamma, loss_type='huber'):
   """Run the training step."""
   online_params = optimizer.target
   def loss_fn(params, target):
@@ -98,8 +92,9 @@ def train(network_def, target_params, optimizer, states, actions, next_states,
     q_values = jax.vmap(q_online)(states).q_values
     q_values = jnp.squeeze(q_values)
     replay_chosen_q = jax.vmap(lambda x, y: x[y])(q_values, actions)
-    loss = jnp.mean(jax.vmap(huber_loss)(target, replay_chosen_q))
-    return loss
+    if loss_type == 'huber':
+      return jnp.mean(jax.vmap(losses.huber_loss)(target, replay_chosen_q))
+    return jnp.mean(jax.vmap(losses.mse_loss)(target, replay_chosen_q))
 
   def q_target(state):
     return network_def.apply(target_params, state)
@@ -225,7 +220,8 @@ class JaxDQNAgent(object):
                summary_writer=None,
                summary_writing_frequency=500,
                allow_partial_reload=False,
-               seed=None):
+               seed=None,
+               loss_type='huber'):
     """Initializes the agent and constructs the necessary components.
 
     Note: We are using the Adam optimizer by default for JaxDQN, which differs
@@ -264,6 +260,7 @@ class JaxDQNAgent(object):
         (for instance, only the network parameters).
       seed: int, a seed for DQN's internal RNG, used for initialization and
         sampling actions. If None, will use the current time in nanoseconds.
+      loss_type: str, whether to use Huber or MSE loss during training.
     """
     assert isinstance(observation_shape, tuple)
     seed = int(time.time() * 1e6) if seed is None else seed
@@ -281,6 +278,7 @@ class JaxDQNAgent(object):
     logging.info('\t max_tf_checkpoints_to_keep: %d',
                  max_tf_checkpoints_to_keep)
     logging.info('\t seed: %d', seed)
+    logging.info('\t loss_type: %s', loss_type)
 
     self.num_actions = num_actions
     self.observation_shape = tuple(observation_shape)
@@ -302,6 +300,7 @@ class JaxDQNAgent(object):
     self.summary_writer = summary_writer
     self.summary_writing_frequency = summary_writing_frequency
     self.allow_partial_reload = allow_partial_reload
+    self._loss_type = loss_type
 
     self._rng = jax.random.PRNGKey(seed)
     state_shape = self.observation_shape + (stack_size,)
@@ -476,7 +475,8 @@ class JaxDQNAgent(object):
                                      self.replay_elements['next_state'],
                                      self.replay_elements['reward'],
                                      self.replay_elements['terminal'],
-                                     self.cumulative_gamma)
+                                     self.cumulative_gamma,
+                                     self._loss_type)
         if (self.summary_writer is not None and
             self.training_steps > 0 and
             self.training_steps % self.summary_writing_frequency == 0):
